import plotly as plt
import plotly.graph_objs as graf

import time
import math

# Average hourly temperatures - midnight - 
# temps = [4, 7, 11, 12, 15, 18, 19, 20, 15, 12, 8, 4]

# 24 hourly readings on 1/1/88: midnight-midnight
# data from https://data.gov.ie/dataset/casement-hourly-weather-station-data
actual_temps = [6.6,6.6,6.7,7.1,7.4,8.4,8.6,9.4,10.1,10.5,11.4,11.9,12.1,12.1,12.1,12.3,12.4,12.6,12.7,12.7,11.6,10.5,9.6,9.5]
num_readings = 24

# Build the model based on the data
x_axis2 = [None] * num_readings*3 # Fill an empty list
for i in range(num_readings*3):
    x_axis2[i] = i+1
print(x_axis2)

baseline = 10 # vertical shift
amplitude = (max(actual_temps) - min(actual_temps))/2
period = (2*math.pi)/num_readings
phase = ((3*math.pi)/2) # sin is at its minimum at 3*pi/2 - this is the horizontal shift

model_temps = []
for month in range(num_readings*3) :
    # sin model: a + b*sin(kt + c)
    temp = baseline + amplitude * math.sin(period*month+phase)
    temp = round(temp, 2)
    model_temps.append(str(temp))

#plot the data  
layoutSettings = graf.Layout(title = "Modelled Data", xaxis = {'title': 'hours'}, yaxis = {'title': 'temperature'})
plotData1 = graf.Scatter(name = "Actual Data", x = x_axis2, y = actual_temps)
plotData2 = graf.Scatter(name = "Model Data", x = x_axis2, y = model_temps)
plt.offline.plot({           
    "data": [plotData1, plotData2],
    "layout": layoutSettings
})